package de.bsvrz.sys.usv.enums;

/**
 * Zuordnung der Zustnde des Attributs KommunikationsZustand der Attributgruppe
 * atg.usvStatus
 * 
 * @author ObertM
 * @author Christian Hsel, BitCtrl Systems GmbH
 * 
 */
public enum KommunikationsZustand {

	/**
	 * Der {@link KommunikationsZustand} "Nicht ermittelbar" (-1).
	 */
	na("nicht ermittelbar", -1),

	/**
	 * Der {@link KommunikationsZustand} "Kommunikationsstrung" (0).
	 */
	Strung("Kommunikationsstrung", 0),

	/**
	 * Der {@link KommunikationsZustand} "in Ordnung" (1).
	 */
	normal("in Ordnung", 1);

	private final String m_text;
	private final int m_value;

	/**
	 * Privater Konstruktor zur Erzeugung eines {@link KommunikationsZustand}es.
	 * 
	 * @param text
	 *            der Name des {@link KommunikationsZustand}es.
	 * @param value
	 *            die Ordinalzahl des {@link KommunikationsZustand}es.
	 */
	private KommunikationsZustand(final String text, final int value) {
		m_text = text;
		m_value = value;
	}

	/**
	 * Liefert den Namen des {@link KommunikationsZustand}es.
	 * 
	 * @return des Name des {@link KommunikationsZustand}es.
	 */
	public String getText() {
		return m_text;
	}

	/**
	 * Liefert die Ordinalzahl des {@link KommunikationsZustand}es.
	 * 
	 * @return die Ordinalzahl des {@link KommunikationsZustand}es.
	 */
	public int getValue() {
		return m_value;
	}
}
