package de.bsvrz.sys.usv.enums;

/**
 * Zuordnung der Zustnde der Attribute ZustandNotstrom der Attributgruppe
 * USV-Status
 * 
 * @author ObertM
 * @author Christian Hsel, BitCtrl Systems GmbH
 * 
 */
public enum ZustandNotstrom {

	/**
	 * Der {@link ZustandNotstrom} "Nicht ermittelbar" (-1).
	 */
	na("nicht ermittelbar", -1),

	/**
	 * Der {@link ZustandNotstrom} "in Ordnung, passiv" (0).
	 */
	passiv("in Ordnung, passiv", 0),

	/**
	 * Der {@link ZustandNotstrom} "in Ordnung, aktiv" (1).
	 */
	aktiv("in Ordnung, aktiv", 1),

	/**
	 * Der {@link ZustandNotstrom} "Strung" (2).
	 */
	Stoerung("Strung", 2);

	private final String m_text;
	private final int m_value;

	/**
	 * Privater Konstruktor zur Erzeugung eines {@link ZustandNotstrom}.
	 * 
	 * @param text
	 *            der Name des {@link ZustandNotstrom}.
	 * @param value
	 *            die Ordinalzahl des {@link ZustandNotstrom}.
	 */
	private ZustandNotstrom(final String text, final int value) {
		m_text = text;
		m_value = value;
	}

	/**
	 * Liefert den Namen eines {@link ZustandNotstrom}.
	 * 
	 * @return der Name des {@link ZustandNotstrom}.
	 */
	public String getText() {
		return m_text;
	}

	/**
	 * Liefert die Ordinalzahl eines {@link ZustandNotstrom}.
	 * 
	 * @return die Ordinalzahl des {@link ZustandNotstrom}.
	 */
	public int getValue() {
		return m_value;
	}
}